@@ -77,7 +77,7 @@ pub struct Tvu {
     accounts_hash_verifier: AccountsHashVerifier,
     cost_update_service: CostUpdateService,
     voting_service: VotingService,
-    warm_quic_cache_service: WarmQuicCacheService,
+    warm_quic_cache_service: Option<WarmQuicCacheService>,
     drop_bank_service: DropBankService,
     transaction_cost_metrics_service: TransactionCostMetricsService,
 }
@@ -151,6 +151,7 @@ impl Tvu {
         block_metadata_notifier: Option<BlockMetadataNotifierLock>,
         wait_to_vote_slot: Option<Slot>,
         pruned_banks_receiver: DroppedSlotsReceiver,
+        use_quic: bool,
     ) -> Self {
         let TvuSockets {
             repair: repair_socket,
@@ -181,6 +182,7 @@ impl Tvu {
             fetch_receiver,
             verified_sender,
             ShredSigVerifier::new(bank_forks.clone(), leader_schedule_cache.clone()),
+            "shred-verifier",
         );
 
         let cluster_slots = Arc::new(ClusterSlots::default());
@@ -286,9 +288,15 @@ impl Tvu {
             bank_forks.clone(),
         );
 
-        let warm_quic_cache_service =
-            WarmQuicCacheService::new(cluster_info.clone(), poh_recorder.clone(), exit.clone());
-
+        let warm_quic_cache_service = if use_quic {
+            Some(WarmQuicCacheService::new(
+                cluster_info.clone(),
+                poh_recorder.clone(),
+                exit.clone(),
+            ))
+        } else {
+            None
+        };
         let (cost_update_sender, cost_update_receiver) = unbounded();
         let cost_update_service =
             CostUpdateService::new(blockstore.clone(), cost_model.clone(), cost_update_receiver);
@@ -382,7 +390,9 @@ impl Tvu {
         self.accounts_hash_verifier.join()?;
         self.cost_update_service.join()?;
         self.voting_service.join()?;
-        self.warm_quic_cache_service.join()?;
+        if let Some(warmup_service) = self.warm_quic_cache_service {
+            warmup_service.join()?;
+        }
         self.drop_bank_service.join()?;
         self.transaction_cost_metrics_service.join()?;
         Ok(())
@@ -507,6 +517,7 @@ pub mod tests {
             None,
             None,
             pruned_banks_receiver,
+            false, // use_quic
         );
         exit.store(true, Ordering::Relaxed);
         tvu.join().unwrap();
