@@ -369,6 +369,7 @@ impl Validator {
         should_check_duplicate_instance: bool,
         start_progress: Arc<RwLock<ValidatorStartProgress>>,
         socket_addr_space: SocketAddrSpace,
+        use_quic: bool,
     ) -> Self {
         let id = identity_keypair.pubkey();
         assert_eq!(id, node.info.id);
@@ -931,6 +932,7 @@ impl Validator {
             block_metadata_notifier,
             config.wait_to_vote_slot,
             pruned_banks_receiver,
+            use_quic,
         );
 
         let tpu = Tpu::new(
@@ -1843,6 +1845,7 @@ mod tests {
             true, // should_check_duplicate_instance
             start_progress.clone(),
             SocketAddrSpace::Unspecified,
+            false, // use_quic
         );
         assert_eq!(
             *start_progress.read().unwrap(),
@@ -1924,6 +1927,7 @@ mod tests {
                     true, // should_check_duplicate_instance
                     Arc::new(RwLock::new(ValidatorStartProgress::default())),
                     SocketAddrSpace::Unspecified,
+                    false, // use_quic
                 )
             })
             .collect();
